'use strict';

const path = require('path');

const CopyWebpackPlugin = require('copy-webpack-plugin');
const angularExternals = require('webpack-angular-externals');
const rxjsExternals = require('webpack-rxjs-externals');
const webpack = require('webpack');

module.exports = {
    entry: {
        'generator-lib-commons-angular5.umd': './src/index.ts',
        'generator-lib-commons-angular5.umd.min': './src/index.ts'
    },
    output: {
        path: path.join(__dirname, 'lib'),
        filename: '[name].js',
        libraryTarget: 'umd',
        library: 'generator-lib-commons-angular5'
    },
    resolve: {
        extensions: [ '.ts', '.js' ]
    },
    externals: [
        angularExternals(),
        rxjsExternals()
    ],
    devtool: 'source-map',
    module: {
        rules: [
            //
            {
                test: /\.ts$/,
                use: [
                    {
                        loader: 'awesome-typescript-loader',
                        options: {
                            configFileName: 'tsconfig.json'
                        }
                    },
                    {
                        loader: 'angular2-template-loader'
                    }
                ],
                exclude: [
                    /node_modules/,
                    /\.(spec|e2e)\.ts$/
                ]
            },

            //
            {
                test: /\.css$/,
                use: ['to-string-loader', 'css-loader']
            },

            //
            {
                test: /\.scss$/,
                use: ['to-string-loader', 'css-loader', 'sass-loader']
            },

            //
            {
                test: /\.html$/,
                use: {
                    loader: 'html-loader',
                    options: {
                        minimize: false,
                        attrs: ['img:src']
                    }
                }
            },

            //
            {
                test: /\.woff(2)?(\?v=[0-9]\.[0-9]\.[0-9])?$/,
                use: {
                    loader: "url-loader",
                    options: {
                        limit: 1000,
                        mimetype: 'application/font-woff',
                        name: 'fonts/[name].[ext]'
                    }
                }
            },
            {
                test: /\.(ttf|eot|svg)(\?v=[0-9]\.[0-9]\.[0-9])?$/,
                use: {
                    loader: "url-loader",
                    options: {
                        limit: 1000,
                        name: 'fonts/[name].[ext]'
                    }
                }
            },

            // -------------------------------------------------------------------
            {
                test: /\.(jpe?g|png|gif)$/i,
                use: [
                    {
                        loader: 'file-loader',
                        options: {
                            name: 'images/[name].[ext]'
                        }
                    }
                ]
            },
        ]
    },
    plugins: [
        //
        new webpack.ContextReplacementPlugin(
            /angular(\\|\/)core(\\|\/)@angular/,
            path.join(__dirname, 'src')
        ),

        //
        new webpack.optimize.UglifyJsPlugin({
            include: /\.min\.js$/,
            sourceMap: true
        }),

        //
        new CopyWebpackPlugin([
            // Copy your files here
        ], {
            // By default, we only copy modified files during a watch or webpack-dev-server build.
            // Setting this to `true` copies all files.
            copyUnmodified: false
        })
    ]
};
